# Python-for-Remote-Sensing-and-GIS
PyRSGIS is a powerful module to read, manipulate and export geo-rasters. The module is built on the GDAL library, and is capable of conducting advanced geospatial analysis. 

Please find the package directly on https://pypi.org/project/pyrsgis/

To install directly using pip, use command:
pip install pyrsgis
